#!/usr/bin/python
# -*- coding: utf-8 -*-

  ############################################################################
  # Copyright (c) 2011, Vasudeva Kamath <kamathvasudev at gmail dot com>     #
  #                                                                          #
  # Permission to use, copy, modify, and/or distribute this software for any #
  # purpose with or without fee is hereby granted, provided that the above   #
  # copyright notice and this permission notice appear in all copies.        #
  #                                                                          #
  # THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES #
  # WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF         #
  # MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR  #
  # ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES   #
  # WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN    #
  # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF  #
  # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.           #
  ############################################################################

__all__ = ["CMU_MALAYALAM_MAP", "CMU_KANNADA_MAP", "CMU_HINDI_MAP"]

CMU_MALAYALAM_MAP = {
    "AA": "ഓ",
    "AH": "അ",
    "AE": "ഏ",
    "AO": "ഓ",
    "AW": "ഔ",
    "AY": "ഐ",
    "B": "ബ്",
    "CH": "ച്ച്",
    "D": "ഡ്",
    "DH": "ദ്",
    "EA": "ഈ",
    "EH": "എ",
    "ER": "എര്‍",
    "EY": "എയ്",
    "F": "ഫ്",
    "G": "ഗ്",
    "HH": "ഹ്",
    "IH": "ഇ",
    "IY": "ഈ",
    "J": "ജ്",
    "JH": "ജ്",
    "K": "ക്",
    "L": "ല്‍",
    "M": "മ്",
    "N": "ന്‍",
    "NG": "ങ്",
    "OW": "ഒ",
    "P": "പ്",
    "R": "ര്‍",
    "S": "സ്",
    "SH": "ഷ്",
    "T": "റ്റ്",
    "TH": "ത്",
    "Y":  "യ്",
    "UW": "ഉ",
    "W": "വ്",
    "V": "വ്",
    "Z": "സ്",
}

CMU_KANNADA_MAP = {
    "AA": "ಆ",
    "AH": "ಅ",
    "AE": "ಏ",
    "AO": "ಓ",
    "AW": "ಔ",
    "AY": "ಐ",
    "B": "ಬ್",
    "CH": "ಚ್",
    "D": "ಡ್",
    "DH": "ದ್",
    "EA": "ಈ",
    "EH": "ಎ",
    "ER": "ಅರ್",
    "EY": "ಎಯ್",
    "F": "ಫ್",
    "G": "ಗ್",
    "HH": "ಹ್",
    "IH": "ಇ",
    "IY": "ಈ",
    "J": "ಜ್",
    "JH": "ಜ್",
    "K": "ಕ್",
    "L": "ಲ್",
    "M": "ಮ್",
    "N": "ನ್",
    "NG": "ಂಗ್",
    "OW": "ಒ",
    "P": "ಪ್",
    "R": "ರ್",
    "S": "ಸ್",
    "SH": "ಷ್",
    "T": "ಟ್",
    "TH": "ತ್",
    "Y":  "ಯ್",
    "UW": "ಊ",
    "UH": "ಉ",
    "W": "ವ್",
    "V": "ವ್",
    "Z": "ಸ್",
    "ZH": "ಷ್",
}

CMU_HINDI_MAP = {
    "AA": "आ",
    "AH": "अ",
    "AE": "ए",
    "AO": "औ",
    "AW": "औ",
    "AY": "ऐ",
    "B": "ब",
    "CH": "च",
    "D": "ड",
    "DH": "द",
    "EA": "ई",
    "EH": "ऐ",
    "ER": "अर",
    "EY": "एय",
    "F": "फ",
    "G": "ग",
    "HH": "ह",
    "IH": "इ",
    "IY": "ई",
    "J": "ज",
    "JH": "झ",
    "K": "क",
    "L": "ल",
    "M": "म",
    "N": "न",
    "NG": "ङ",
    "OW": "ओ",
    "P": "प",
    "R": "र",
    "S": "स",
    "SH": "ष",
    "T": "ट",
    "TH": "त",
    "Y":  "य",
    "UW": "ऊ",
    "UH": "उ",
    "W": "व",
    "V": "भ",
    "Z": "ज़",
    "ZH": "श",
}



#! /usr/bin/env python
# -*- coding: utf-8 -*-
# Any Indian Language to any other Indian language transliterator
# Copyright 2008-2010 Santhosh Thottingal <santhosh.thottingal@gmail.com>
# http://www.smc.org.in
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# If you find any bugs or have any suggestions email:
# santhosh.thottingal@gmail.com
# URL: http://www.smc.org.in

import os
from cmumapping import *


class CMUDict():
    def __init__(self):
        self.dictionaryfile = os.path.join(os.path.dirname(__file__),
                                           'cmudict.0.7a_SPHINX_40')
        self.cmudictionary = None

    def load(self):
        fdict = open(self.dictionaryfile, "r")
        flines = fdict.readlines()
        linecount = len(flines)
        self.cmudictionary = dict()
        for line in flines:
            line = line.strip()
            lhs = line.split()[0]
            rhs = line.split()[1:]
            self.cmudictionary[lhs] = rhs

    def find(self, word):
        if self.cmudictionary is None:
            self.load()
        return self.cmudictionary[word.upper()]

    def pronunciation(self, word, language):
        stripped_word = word.strip('!,.?:')
        punctuations = word[len(stripped_word):]
        try:
            cmu_pronunciation = self.find(stripped_word)
        except KeyError:
            #print "could not find the word" + stripped_word + " in dictionary"
            return word
        pronunciation_str = ""
        if language == "ml_IN":
            for syl in cmu_pronunciation:
                try:
                    pronunciation_str += CMU_MALAYALAM_MAP[syl]
                except KeyError:
                    pronunciation_str += syl
            pronunciation_str = self._fix_vowel_signs_ml(pronunciation_str)

        if language == "kn_IN":
            for symbol in cmu_pronunciation:
                try:
                    pronunciation_str += CMU_KANNADA_MAP[symbol]
                except KeyError:
                    pronunciation_str += symbol
                pronunciation_str = self._fix_vowel_signs_kn(pronunciation_str)

        if language == "hi_IN":
            for symbol in cmu_pronunciation:
                try:
                    pronunciation_str += CMU_HINDI_MAP[symbol]
                except KeyError:
                    pronunciation_str += symbol
                pronunciation_str = self._fix_vowel_signs_hi(pronunciation_str)
        return (pronunciation_str).decode("utf-8") + punctuations

    def _fix_vowel_signs_ml(self, text):
        text = text.replace("്അ", "")
        text = text.replace("്‍അ", "")
        text = text.replace("്ആ", "ാ")
        text = text.replace("്‍ആ", "ാ")
        text = text.replace("്ഇ", "ി")
        text = text.replace("്‍ഇ", "ി")
        text = text.replace("്ഈ", "ീ")
        text = text.replace("്‍ഈ", "ീ")
        text = text.replace("്ഉ", "ു")
        text = text.replace("്‍ഉ", "ു")
        text = text.replace("്ഊ", "ൂ")
        text = text.replace("്‍ഊ", "ൂ")
        text = text.replace("്റ", "്ര")
        text = text.replace("്എ", "െ")
        text = text.replace("്‍എ", "")
        text = text.replace("്ഏ", "േ")
        text = text.replace("്‍ഏ", "േ")
        text = text.replace("്ഐ", "ൈ")
        text = text.replace("്‍ഐ", "ൈ")
        text = text.replace("്ഒ", "ൊ")
        text = text.replace("്‍ഒ", "ൊ")
        text = text.replace("്ഓ", "ോ")
        text = text.replace("്‍ഓ", "ോ")
        text = text.replace("്ഔ", "ൌ")
        text = text.replace("്‍ഔ", "ൌ")
        text = text.replace("ര്ര", "റ്റ")
        text = text.replace("റ്ര", "റ്റ")
        text = text.replace("ന്‍റ്റ", "ന്റ")
        return text

    def _fix_vowel_signs_kn(self, text):
        text = text.replace("್ಅ", "")
        text = text.replace("್ಆ", "ಾ")
        text = text.replace("್ಇ", "ಿ")
        text = text.replace("್ಈ", "ೀ")
        text = text.replace("್ಉ", "ು")
        text = text.replace("್ಊ", "ೂ")
        text = text.replace("್ಋ", "ೃ")
        text = text.replace("್ಎ", "ೆ")
        text = text.replace("್ಏ", "ೇ")
        text = text.replace("್ಐ", "ೈ")
        text = text.replace("್ಒ", "ೊ")
        text = text.replace("್ಓ", "ೋ")
        text = text.replace("್ಔ", "ೌ")
        return text

    def _fix_vowel_signs_hi(self, text):
        text = text.replace("अ", "")
        text = text.replace("आ", "ा")
        text = text.replace("इ", "ि")
        text = text.replace("ई", "ी")
        text = text.replace("उ", "ु")
        text = text.replace("ऊ", "ू")
        text = text.replace("ऋ", "ृ")
        text = text.replace("ए", "े")
        text = text.replace("ऐ", "ै")
        text = text.replace("ओ", "ो")
        text = text.replace("औ", "ौ")
        text = text.replace("ङ", "न्")
        return text



#! /usr/bin/env python
# -*- coding: utf-8 -*-
# Any Indian Language to any other Indian language transliterator
# Copyright 2009-2010 Santhosh Thottingal <santhosh.thottingal@gmail.com>
# http://www.smc.org.in
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# If you find any bugs or have any suggestions
# email: santhosh.thottingal@gmail.com
# URL: http://www.smc.org.in

__all__ = ['Transliterator', 'getInstance']

import string
import normalizer
from cmudict import CMUDict
import indic_en
from silpa_common.langdetect import detect_lang
from silpa_common.charmap import charmap

lang_bases = {
    'en_US': 0, 'en_IN': 0, 'hi_IN': 0x0901, 'bn_IN': 0x0981,
    'pa_IN': 0x0A01, 'gu_IN': 0x0A81, 'or_IN': 0x0B01, 'ta_IN': 0x0B81,
    'te_IN': 0x0C01, 'kn_IN': 0x0C81, 'ml_IN': 0x0D01
}


class Transliterator:
    def __init__(self):
        self.cmu = CMUDict()
        self.normalizer = normalizer.getInstance()

    def transliterate_en_ml(self, word):
        """
        Transliterate English to Malayalam with the help of
        CMU pronuciation dictionary
        """
        return self.cmu.pronunciation(word, "ml_IN")

    def transliterate_en_kn(self, word):
        """
        Transliterate English to Kannada with the help of
        CMU pronuciation dictionary
        """
        return self.cmu.pronunciation(word, "kn_IN")

    def transliterate_en_hi(self, word):
        """
        Transliterate English to Hindi with the help of
        CMU pronuciation dictionary
        """
        return self.cmu.pronunciation(word, "hi_IN")

    def transliterate_en_xx(self, word, target_lang):
        """
        Transliterate English to any Indian Language.
        """
        if target_lang == "en_IN" or target_lang == "en_US":
            return word
        if target_lang == "kn_IN":
            tx_str = self.transliterate_en_kn(word)
            return tx_str
        elif target_lang == "hi_IN":
            tx_str = self.transliterate_en_hi(word)
            return tx_str
        else:
            tx_str = self.transliterate_en_ml(word)

        if target_lang == "ml_IN":
            return tx_str
        #chain it through indic indic transliteratioin
        #first remove malayalam specific zwj
        tx_str = tx_str.replace(u'‍', '')  # remove instances of zwnj
        if tx_str[-1:] == u'്' and \
           (target_lang == "hi_IN"
            or target_lang == "gu_IN"
            or target_lang == "bn_IN"): tx_str = tx_str[:-(len(u'്'))]
        # remove the last virama'
        return self.transliterate_indic_indic(tx_str, "ml_IN", target_lang)

    def transliterate_xx_en(self, word, src_lang):
        """
        Transliterate Indian Language to English.
        """
        if src_lang == "en_IN" or src_lang == "en_US":
            return word

        # TODO: the function is generic now so no need of testing the lanuguage
        # but since the indic_en contains only for kn_IN and ml_IN we need this
        # check.
        # Add all indic language to indic_en
        # remplace this block with single call to indic_en function
        if src_lang == "kn_IN":
            return self.transliterate_indic_en(word, src_lang)
        if not src_lang == "ml_IN":
            word = self.transliterate_indic_indic(word, src_lang, "ml_IN")

        return self.transliterate_indic_en(word, "ml_IN")

    def transliterate_iso15919(self, word, src_language):
        tx_str = ""
        index = 0
        word_length = len(word)
        for chr in word:
            index += 1
            offset = ord(chr) - lang_bases[src_language]
            #76 is the virama offset for all indian languages from its base
            if offset >= 61 and offset <= 76:
                tx_str = tx_str[:-1]  # remove the last 'a'
            if offset > 0 and offset <= 128:
                tx_str = tx_str + charmap["ISO15919"][offset]
            #delete the inherent 'a' at the end of the word from hindi
            if tx_str[-1:] == 'a' and (src_language == "hi_IN"
                                       or src_language == "gu_IN"
                                       or src_language == "bn_IN"):
                if word_length == index and word_length > 1:  # if last letter
                    tx_str = tx_str[:-1]  # remove the last 'a'
        return tx_str .decode("utf-8")

    def transliterate_ipa(self, word, src_language):
        """
        Transliterate the given word in src_language to
        IPA - International Phonetical Alphabet notation.
        """
        tx_str = ""
        index = 0
        word_length = len(word)
        for chr in word:
            index += 1
            if ord(chr) < 255:  # ASCII characters + English
                tx_str += chr
                continue
            offset = ord(chr) - lang_bases[src_language]
            #76 is the virama offset for all indian languages from its base
            if offset >= 61 and offset <= 76:
                tx_str = tx_str[:-(len('ə'))]  # remove the last 'ə'
            if offset > 0 and offset <= 128:
                tx_str = tx_str + charmap["IPA"][offset]
            #delete the inherent 'a' at the end of the word from hindi
            if tx_str[-1:] == 'ə' and \
               (src_language == "hi_IN"
                or src_language == "gu_IN"
                or src_language == "bn_IN") and \
               (word_length == index
                and word_length > 1): tx_str = tx_str[:-(len('ə'))]
            # if last letter
            # remove the last 'a'
        return tx_str.decode("utf-8")

    def _malayalam_fixes(self, text):
        try:
            text = text.replace(u"മ് ", u"ം ")
            text = text.replace(u"മ്,", u"ം,")
            text = text.replace(u"മ്.", u"ം.")
            text = text.replace(u"മ്)", u"ം)")
            text = text.replace(u"ഩ", u"ന")
            text = text.replace(u"൤", u".")  # danda by fullstop
        except:
            pass
        return text

    def transliterate_indic_indic(self, word, src_lang, target_lang):
        """
            Transliterate from an Indian languge word
            to another indian language word
        """
        index = 0
        tx_str = ""
        word = self.normalizer.normalize(word)
        if src_lang == "ml_IN" and target_lang != "ml_IN":
            word = word.replace(u"\u200C", u"")
            word = word.replace(u"\u200D", u"")
            #replace all samvruthokaram by u vowels
            word = word.replace(u"ു്", u"")

        for chr in word:
            index += 1
            if chr in string.punctuation or (ord(chr) <= 2304
                                             and ord(chr) >= 3071):
                tx_str = tx_str + chr
                continue
            offset = ord(chr) + self.getOffset(src_lang, target_lang)
            if(offset > 0):
                tx_str = tx_str + unichr(offset)
            #schwa deletion
            baseoffset = offset - lang_bases[target_lang]
            #76 : virama
            if (index == len(word) and baseoffset == 76
                    and (target_lang == "hi_IN"
                         or target_lang == "gu_IN"
                         or target_lang == "pa_IN"
                         or target_lang == "bn_IN")):
                #TODO Add more languages having schwa deletion characteristic
                tx_str = tx_str[:-(len(chr))]  # remove the last 'a'

            if target_lang == "ml_IN" and src_lang == "ta_IN":
                tx_str = tx_str.replace(u"ഩ", u"ന")

            if target_lang == "ta_IN":
                tx_str = tx_str.replace(u'\u0B96', u"க")
                tx_str = tx_str.replace(u'\u0B97', u"க")
                tx_str = tx_str.replace(u'\u0B98', u"க")
                tx_str = tx_str.replace(u'\u0B9B', u"ச")
                tx_str = tx_str.replace(u'\u0B9D', u"ச")
                tx_str = tx_str.replace(u'\u0BA0', u"ட")
                tx_str = tx_str.replace(u'\u0BA1', u"ட")
                tx_str = tx_str.replace(u'\u0BA2', u"ட")
                tx_str = tx_str.replace(u'\u0BA5', u"த")
                tx_str = tx_str.replace(u'\u0BA6', u"த")
                tx_str = tx_str.replace(u'\u0BA7', u"த")
                tx_str = tx_str.replace(u'\u0BAB', u"ப")
                tx_str = tx_str.replace(u'\u0BAC', u"ப")
                tx_str = tx_str.replace(u'\u0BAD', u"ப")
                tx_str = tx_str.replace(u'\u0BC3', u"ிரு")
                tx_str = tx_str.replace(u'ஂ', u'ம்')
        #If target is malayalam, we need to add the virama
        if ((target_lang == "ml_IN") and
            (src_lang == "hi_IN"
             or src_lang == "gu_IN"
             or src_lang == "pa_IN"
             or src_lang == "bn_IN") and tx_str[-1].isalpha()):
            tx_str = tx_str + u"്"
        return tx_str

    def transliterate_indic_en(self, word, src_lang):
        """
        Arguments:
        - `self`:
        - `word`: Word to be transliterated (sentence)
        - `src_lang`: Language from which we need to transilterate
        """

        # Get all the language related stuffs
        dictionary = indic_en.get_dictionary_for(src_lang)
        vowels = indic_en.get_vowels_for(src_lang)
        vowel_signs = indic_en.get_vowel_signs_for(src_lang)
        virama = indic_en.get_virama_for(src_lang)
        anuswara = indic_en.get_anuswara_for(src_lang)

        word_length = len(word)
        index = 0
        tx_string = ""
        while index < word_length:

            # If current charachter is a punctuation symbol
            # skip it.
            # Added to avoid getting extra 'a' to the begining
            # of word next to punctuation symbol
            #

            if word[index] in string.punctuation:
                tx_string += word[index]
                index += 1
                continue

            # Virama = conjucter
            if word[index] == virama:
                index += 1
                continue

            # Get english equivalaent of the charachter.
            try:
                tx_string += dictionary[word[index]]
            except KeyError:
                # If charachter isn't present in the dict
                # just append the charachter to string
                # This case is now handled by punctuation checking
                tx_string += word[index]

            if index + 1 < word_length and not word[index + 1] in vowel_signs \
                    and word[index + 1] in dictionary \
                    and not word[index] in vowels \
                    and not word[index] in vowel_signs:
                tx_string += 'a'

            if index + 1 == word_length and not word[index] in vowel_signs \
                    and word[index] in dictionary:
                tx_string += 'a'

            #handle am sign
            if index + 1 < word_length and word[index + 1] == anuswara \
                    and not word[index] in vowel_signs:
                tx_string += 'a'
            index += 1
        return tx_string

    def transliterate(self, text, target_lang_code):
        tx_str = ""
        lines = text.split("\n")
        for line in lines:
            words = line.split(" ")
            for word in words:
                if(word.strip() > ""):
                    try:
                        src_lang_code = detect_lang(word)[word]
                    except:
                        tx_str = tx_str + " " + word
                        continue  # FIXME

                    if target_lang_code == "ISO15919":
                        tx_str = (tx_str
                                  + self.transliterate_iso15919(word,
                                                                src_lang_code)
                                  + " ")
                        continue

                    if target_lang_code == "IPA":
                        tx_str = (tx_str
                                  + self.transliterate_ipa(word,
                                                           src_lang_code)
                                  + " ")
                        continue

                    if src_lang_code == "en_US":
                        tx_str = (tx_str
                                  + self.transliterate_en_xx(word,
                                                             target_lang_code)
                                  + " ")
                        continue

                    if target_lang_code == "en_US" or \
                            target_lang_code == "en_IN":
                        tx_str = (tx_str
                                  + self.transliterate_xx_en(word,
                                                             src_lang_code)
                                  + " ")
                        continue

                    tx_str += self.transliterate_indic_indic(word,
                                                             src_lang_code,
                                                             target_lang_code)

                    if len(line) > 1:
                        tx_str += " "

                else:
                    tx_str = tx_str + word
            if len(lines) > 1:
                tx_str += "\n"
        # Language specific fixes
        if target_lang_code == "ml_IN":
            tx_str = self._malayalam_fixes(tx_str)
        return tx_str

    def getOffset(self, src, target):
        src_id = 0
        target_id = 0
        try:
            src_id = lang_bases[src]
            target_id = lang_bases[target]
            return (target_id - src_id)
        except:
            return 0

    def get_module_name(self):
        return "Transliterator"

    def get_info(self):
        return "Transliterate the text between any Indian Language"


def getInstance():
    return Transliterator()



#!/usr/bin/python
#-*- coding: utf-8 -*-
import sys
sys.path.append('..')
import transliteration
import unittest


class TransliterationTest(unittest.TestCase):
    def setUp(self):
        self.t = transliteration.getInstance()
        self.kn = u"ನಮಸ್ಕಾರ ಇದು ಕನ್ನಡ ಪಠ್ಯ ಟ್ರಾನ್ಸ್ಲಿಟರೇಷನ್ ಪರೀಕ್ಷೆಗಾಗಿ"
        self.hi = u"नमस्कार सिल्पा की दुनिया में आपका स्वागत है"
        self.en = "This is a english text for transliteration"

    def testKannadaToEnglish(self):
        result = self.t.transliterate(self.kn, "en_US")
        print result.encode('utf-8')
        self.assertEqual(result.strip(),
                         "namaskaara idu kannaDa paThya"
                         " TraansliTareshhan parikshhegaagi")

    def testEnglishToKannada(self):
        result = self.t.transliterate(self.en, "kn_IN")
        print result.encode('utf-8')
        self.assertEqual(result.strip(),
                         u"ದಿಸ್ ಇಸ್ ಅ ಇಂಗ್ಗ್ಲಿಷ್ ಟೆಕ್ಸ್ಟ್ ಫೋರ್"
                         " transliteration")

    def testKannadaToTamil(self):
        result = self.t.transliterate(self.kn, "ta_IN")
        print result.encode('utf-8')
        self.assertEqual(result,
                         u"நமஸ்காரஇதுகந்நடபட்யட்ராந்ஸ்லிடரேஷந்பரீக்ஷெகாகி")

    def testEnglishToHindi(self):
        result = self.t.transliterate(self.en, "hi_IN")
        print result.encode('utf-8')
        self.assertEqual(result.strip(),
                         u"दिस इज़  इन्गलिष टैक्स्ट फौर transliteration")

    def testHindiToEnglish(self):
        result = self.t.transliterate(self.hi, "en_US")
        print result.encode('utf-8')
        self.assertEqual(result.strip(),
                         u"namaskaar silpaa kee duniyaa mem"
                         " aapakaa svaagath hai")

if __name__ == "__main__":
    suite = unittest.TestLoader().loadTestsFromTestCase(TransliterationTest)
    unittest.TextTestRunner(verbosity=2).run(suite)



from setuptools import setup, find_packages

name='transliteration'

setup (
    name=name,
    version="0.4.1",
    url="http://silpa.org.in/Transliterate",
    license="LGPL 3.0",
    description="Indian Language Transliteration Library",
    author='Santhosh Thottingal',
    author_email="santhosh.thottingal@gmail.com",
    long_description="""This library helps in transliteration
from English to Indian Language and from one Indian Language
to another Indian Language.""",
    include_package_data=True,    
    packages=find_packages(exclude='tests'),
    setup_requires=['setuptools-git'],
    install_requires=['setuptools','normalizer','silpa_common'],
    zip_safe=False,
    )



#!/usr/bin/python
# -*- coding: utf-8 -*-
#indic_en.py
#
#Copyright 2010 Vasudev Kamath <kamathvasudev@gmail.com>
#
#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU  General Public License as published by
#the Free Software Foundation; either version 3 of the License, or
#(at your option) any later version.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#MA 02110-1301, USA.
#
'''
This file contains all language related dictionaries vowel and vowel signs
and function which returns a dictionary or vowel or vowel signs for a language

Trying to make indic_en transliteration more generic
'''
__all__ = ['kannada_english_dict', 'kn_vowels', 'kn_vowel_signs',
           'malayalam_english_dict', 'ml_vowels', 'ml_vowel_signs',
           'hindi_english_dict', 'hi_vowels', 'hi_vowel_signs',
           'language_dictionary', 'language_vowels', 'language_vowel_signs',
           'language_virama', 'language_anuswara', 'get_dictionary_for',
           'get_anuswara_for', 'get_vowels_for', 'get_virama_for',
           'get_vowel_signs_for']

kannada_english_dict = {
    u'ಅ': 'a', u'ಆ': 'aa', u'ಇ': 'i', u'ಈ': 'i', u'ಉ': 'u',
    u'ಊ': 'u', u'ಋ': 'rri', u'ಎ': 'e', u'ಏ': 'e', u'ಐ': 'ai',
    u'ಒ': 'o', u'ಓ': 'o', u'ಔ': 'au', u'ಂ': 'm', u'ಃ': 'h',
    u'ಕ': 'k', u'ಖ': 'kh', u'ಗ': 'g', u'ಘ': 'gh', u'ಙ': 'ng',
    u'ಚ': 'ch', u'ಛ': 'chh', u'ಜ': 'j', u'ಝ': 'jhh', u'ಞ': 'nj',
    u'ತ': 'th', u'ಥ': 'thh', u'ದ': 'd', u'ಧ': 'dh', u'ನ': 'n',
    u'ಟ': 'T', u'ಠ': 'Th', u'ಡ': 'D', u'ಢ': 'Dh', u'ಣ': 'N',
    u'ಪ': 'p', u'ಫ': 'ph', u'ಬ': 'b', u'ಭ': 'bh', u'ಮ': 'm',
    u'ಯ': 'y', u'ರ': 'r', u'ಲ': 'l', u'ವ': 'v', u'ಶ': 'sh',
    u'ಷ': 'shh', u'ಸ': 's', u'ಹ': 'h', u'ಳ': 'L',
    u'ಋ': 'rri', u'್': '', u'ಾ': 'aa', u'ಿ': 'i', u'ೀ': 'i',
    u'ು': 'u', u'ೂ': 'u', u'ೃ': 'rri', u'ೆ': 'e', u'ೇ': 'e',
    u'ೈ': 'ai', u'ೊ': 'o', u'ೋ': 'o', u'ೌ': 'au',
    u'ಕ್ಷ': 'ksh', u'ತ್ರ': 'tr', u'ಜ್ಞ': 'jn',
    u'೧': '1', u'೨': '2', u'೩': '3', u'೪': '4', u'೫': '5',
    u'೬': '6', u'೭': '7', u'೮': '8', u'೯': '9', u'೦': '0'
}

kn_vowels = [u'ಅ', u'ಆ', u'ಇ', u'ಈ', u'ಉ', u'ಊ', u'ಋ', u'ಎ', u'ಏ', u'ಐ',
             u'ಒ', u'ಓ', u'ಔ']
kn_vowel_signs = [u'್', u'ಾ', u'ಿ', u'ೀ', u'ು', u'ೂ', u'ೃ', u'ೆ', u'ೇ',
                  u'ೈ', u'ೊ', u'ೋ', u'ೌ', u'ಂ', u'ಃ', u' ']

malayalam_english_dict = {
    u'അ': 'a', u'ആ': 'aa', u'ഇ': 'i', u'ഈ': 'ee', u'ഉ': 'u', u'ഊ': 'oo',
    u'ഋ': 'ri',
    u'എ': 'e', u'ഏ': 'e', u'ഐ': 'ai', u'ഒ': 'o', u'ഓ': 'o', u'ഔ': 'au',
    u'ക': 'k', u'ഖ': 'kh', u'ഗ': 'g', u'ഘ': 'gh', u'ങ്ങ': 'ng',
    u'ങ': 'ng',
    u'ച': 'ch', u'ഛ': 'chh', u'ജ': 'j', u'ഝ': 'jhh', u'ഞ': 'nj',
    u'ട': 't', u'ഠ': 'th', u'ഡ': 'd', u'ഢ': 'dh', u'ണ': 'n',
    u'ത': 'th', u'ഥ': 'th', u'ദ': 'd', u'ധ': 'dh', u'ന': 'n',
    u'പ': 'p', u'ഫ': 'ph', u'ബ': 'b', u'ഭ': 'bh', u'മ': 'm',
    u'യ': 'y', u'ര': 'r', u'ല': 'l',  u'വ': 'v',  u'റ': 'r',
    u'ശ': 's', u'ഷ': 'sh', u'സ': 's',  u'ഹ': 'h', u'ള': 'l', u'ഴ': 'zh',
    u'്': '', u'ം': 'm', u'ാ': 'aa', u'ി': 'i', u'ീ': 'ee', u'ു': 'u',
    u'ൂ': 'oo', u'ൃ': 'ri', u'െ': 'e', u'േ': 'e',
    u'ൈ': 'ai', u'ൊ': 'o', u'ോ': 'oo', u'ൗ': 'au', u'ൌ': 'ou'
}

ml_vowels = [u'അ', u'ആ', u'ഇ', u'ഈ', u'ഉ', u'ഊ', u'ഋ', u'എ', u'ഏ', u'ഐ',
             u'ഒ', u'ഓ', u'ഔ']
ml_vowel_signs = [u'്', u'ം', u'ാ', u'ി', u'ീ', u'ു', u'ൂ', u'ൃ', u'െ', u'േ',
                  u'ൈ', u'ൊ', u'ോ', u'ൗ',  u'ൌ', u'‍']

hindi_english_dict = {
    u'अ': 'a', u'आ': 'aa', u'इ': 'i', u'ई': 'i', u'उ': 'u',
    u'ऊ': 'u', u'ऋ': 'rri', u'ए': 'e', u'ऐ': 'ai',
    u'ओ': 'o', u'औ': 'au', u'ं': 'm', u'ಃ': 'h',
    u'क': 'k', u'ख': 'kh', u'ग': 'g', u'घ': 'gh', u'ङ': 'ng',
    u'च': 'ch', u'छ': 'chh', u'ज': 'j', u'झ': 'jhh', u'ञ': 'nj',
    u'ट': 'th', u'ठ': 'thh', u'ड': 'd', u'ढ': 'dh', u'ण': 'n',
    u'त': 'T', u'थ': 'Th', u'द': 'D', u'ध': 'Dh', u'न': 'N',
    u'प': 'p', u'फ': 'ph', u'ब': 'b', u'भ': 'bh', u'म': 'm',
    u'य': 'y', u'र': 'r', u'ल': 'l', u'व': 'v', u'ष': 'sh',
    u'श': 'shh', u'स': 's', u'ह': 'h', u'ಳ': 'L',
    u'ृ': 'rri', u'ा': 'aa', u'ि': 'i', u'ी': 'i',
    u'ु': 'u', u'ू': 'u', u'ृ': 'rri', u'े': 'e', u'ॆ': 'e',
    u'ै': 'ai', u'ो': 'o', u'ॊ': 'o', u'ौ': 'au',
    u'क्ष': 'ksh', u'त्र': 'tr', u'ज्ञ': 'jn',
    u'೧': '१', u'२': '2', u'३': '3', u'೪': '4', u'५': '5',
    u'६': '6', u'७': '7', u'८': '8', u'९': '9', u'०': '0'
}

hi_vowels = [u'अ', u'आ', u'इ', u'ई', u'उ' u'ऊ', u'ऋ', u'ए',
             u'ऐ', u'ओ', u'औ']
hi_vowel_signs = [u'', u'ा', u'ि', u'ी', u'ु', u'ू', u'ृ', u'े', u'ॆ',
                  u'ै', u'ो', u'ॊ', u'ौ', u'ं', u'ಃ']

# P.S: Please declare all language related variables above this and
# fill in the following mapping as you add dictionary vowels and
# vowel_signs for your language


# language dictionary mapping
language_dictionary = {"kn_IN": kannada_english_dict,
                       "ml_IN": malayalam_english_dict,
                       "hi_IN": hindi_english_dict}

# language vowels mapping
language_vowels = {"kn_IN": kn_vowels,
                   "ml_IN": ml_vowels,
                   "hi_IN": hi_vowels}

# language vowel signs mapping
language_vowel_signs = {"kn_IN": kn_vowel_signs,
                        "ml_IN": ml_vowel_signs,
                        "hi_IN": hi_vowel_signs}

# language virama sign mapping
language_virama = {"kn_IN": u"್", "ml_IN": u"്", "hi_IN": u"्"}
# language anuswara sign mapping
language_anuswara = {"kn_IN": u"ಂ", "ml_IN": u'ം', "hi_IN": "ं"}


def get_dictionary_for(lang="ml_IN"):
    """
     Returns the 'language'_english_dict if there
     is no dictionary available for a language then
     return ml_IN dictionary
     i.e cycle through language -> ml_IN -> en_US
    Arguments:
    - `lang`: Language for which dictionary is required
    """
    return language_dictionary.get(lang, "ml_IN")


def get_vowels_for(lang="ml_IN"):
    """
    Returns the 'lang'_vowels list. If vowel list
    is not available for a language retrun list for
    ml_IN

    Arguments:
    - `lang`: Language for which vowel list should be returned
    """

    return language_vowels.get(lang, "ml_IN")


def get_vowel_signs_for(lang="ml_IN"):
    """
    Returns the 'lang'_vowels list. If vowel list
    is not available for a language retrun list for
    ml_IN

    Arguments:
    - `lang`: Language for which vowel signs list should be returned
    """

    return language_vowel_signs.get(lang, "ml_IN")


def get_virama_for(lang="ml_IN"):
    """
    Return the virama symbol for given language
    Arguments:
    - `lang`: Language for which virama symbol should be returned
    """

    return language_virama.get(lang, "ml_IN")


def get_anuswara_for(lang="ml_IN"):
    """
    Return the anuswara symbol for the language
    Arguments:
    - `lang`: Language for which anuswara symbol is needed
    """

    return language_anuswara.get(lang, "ml_IN")
